# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: feast_spark/api/JobService.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from feast.core import DataSource_pb2 as feast_dot_core_dot_DataSource__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n feast_spark/api/JobService.proto\x12\x0f\x66\x65\x61st_spark.api\x1a\x1b\x66\x65\x61st/core/DataSource.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"\x9b\x04\n\x03Job\x12\n\n\x02id\x18\x01 \x01(\t\x12&\n\x04type\x18\x02 \x01(\x0e\x32\x18.feast_spark.api.JobType\x12*\n\x06status\x18\x03 \x01(\x0e\x32\x1a.feast_spark.api.JobStatus\x12\x0c\n\x04hash\x18\x04 \x01(\t\x12.\n\nstart_time\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12:\n\tretrieval\x18\x06 \x01(\x0b\x32%.feast_spark.api.Job.RetrievalJobMetaH\x00\x12\x43\n\x0f\x62\x61tch_ingestion\x18\x07 \x01(\x0b\x32(.feast_spark.api.Job.OfflineToOnlineMetaH\x00\x12\x43\n\x10stream_ingestion\x18\x08 \x01(\x0b\x32\'.feast_spark.api.Job.StreamToOnlineMetaH\x00\x12\x0f\n\x07log_uri\x18\t \x01(\t\x12\x15\n\rerror_message\x18\n \x01(\t\x1a+\n\x10RetrievalJobMeta\x12\x17\n\x0foutput_location\x18\x01 \x01(\t\x1a)\n\x13OfflineToOnlineMeta\x12\x12\n\ntable_name\x18\x01 \x01(\t\x1a(\n\x12StreamToOnlineMeta\x12\x12\n\ntable_name\x18\x01 \x01(\tB\x06\n\x04meta\"\xc5\x01\n\'StartOfflineToOnlineIngestionJobRequest\x12\x0f\n\x07project\x18\x01 \x01(\t\x12\x12\n\ntable_name\x18\x02 \x01(\t\x12.\n\nstart_date\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12,\n\x08\x65nd_date\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x17\n\x0f\x64\x65lta_ingestion\x18\x05 \x01(\x08\"\x8f\x01\n(StartOfflineToOnlineIngestionJobResponse\x12\n\n\x02id\x18\x01 \x01(\t\x12\x32\n\x0ejob_start_time\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x12\n\ntable_name\x18\x03 \x01(\t\x12\x0f\n\x07log_uri\x18\x04 \x01(\t\"\x84\x01\n*ScheduleOfflineToOnlineIngestionJobRequest\x12\x0f\n\x07project\x18\x01 \x01(\t\x12\x12\n\ntable_name\x18\x02 \x01(\t\x12\x1a\n\x12ingestion_timespan\x18\x03 \x01(\x05\x12\x15\n\rcron_schedule\x18\x04 \x01(\t\"-\n+ScheduleOfflineToOnlineIngestionJobResponse\"S\n,UnscheduleOfflineToOnlineIngestionJobRequest\x12\x0f\n\x07project\x18\x01 \x01(\t\x12\x12\n\ntable_name\x18\x02 \x01(\t\"/\n-UnscheduleOfflineToOnlineIngestionJobResponse\"\xa4\x01\n\x1cGetHistoricalFeaturesRequest\x12\x14\n\x0c\x66\x65\x61ture_refs\x18\x01 \x03(\t\x12-\n\rentity_source\x18\x02 \x01(\x0b\x32\x16.feast.core.DataSource\x12\x0f\n\x07project\x18\x03 \x01(\t\x12\x17\n\x0foutput_location\x18\x04 \x01(\t\x12\x15\n\routput_format\x18\x05 \x01(\t\"\x89\x01\n\x1dGetHistoricalFeaturesResponse\x12\n\n\x02id\x18\x01 \x01(\t\x12\x17\n\x0foutput_file_uri\x18\x02 \x01(\t\x12\x32\n\x0ejob_start_time\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x0f\n\x07log_uri\x18\x04 \x01(\t\"R\n\x0fListJobsRequest\x12\x1a\n\x12include_terminated\x18\x01 \x01(\x08\x12\x12\n\ntable_name\x18\x02 \x01(\t\x12\x0f\n\x07project\x18\x03 \x01(\t\"6\n\x10ListJobsResponse\x12\"\n\x04jobs\x18\x01 \x03(\x0b\x32\x14.feast_spark.api.Job\"\x1f\n\rGetJobRequest\x12\x0e\n\x06job_id\x18\x01 \x01(\t\"3\n\x0eGetJobResponse\x12!\n\x03job\x18\x01 \x01(\x0b\x32\x14.feast_spark.api.Job\"\"\n\x10\x43\x61ncelJobRequest\x12\x0e\n\x06job_id\x18\x01 \x01(\t\"\x13\n\x11\x43\x61ncelJobResponse\"?\n\x17GetHealthMetricsRequest\x12\x0f\n\x07project\x18\x01 \x01(\t\x12\x13\n\x0btable_names\x18\x02 \x03(\t\":\n\x18GetHealthMetricsResponse\x12\x0e\n\x06passed\x18\x01 \x03(\t\x12\x0e\n\x06\x66\x61iled\x18\x02 \x03(\t*`\n\x07JobType\x12\x0f\n\x0bINVALID_JOB\x10\x00\x12\x17\n\x13\x42\x41TCH_INGESTION_JOB\x10\x01\x12\x18\n\x14STREAM_INGESTION_JOB\x10\x02\x12\x11\n\rRETRIEVAL_JOB\x10\x04*~\n\tJobStatus\x12\x16\n\x12JOB_STATUS_INVALID\x10\x00\x12\x16\n\x12JOB_STATUS_PENDING\x10\x01\x12\x16\n\x12JOB_STATUS_RUNNING\x10\x02\x12\x13\n\x0fJOB_STATUS_DONE\x10\x03\x12\x14\n\x10JOB_STATUS_ERROR\x10\x04\x32\xc3\x07\n\nJobService\x12\x97\x01\n StartOfflineToOnlineIngestionJob\x12\x38.feast_spark.api.StartOfflineToOnlineIngestionJobRequest\x1a\x39.feast_spark.api.StartOfflineToOnlineIngestionJobResponse\x12\xa0\x01\n#ScheduleOfflineToOnlineIngestionJob\x12;.feast_spark.api.ScheduleOfflineToOnlineIngestionJobRequest\x1a<.feast_spark.api.ScheduleOfflineToOnlineIngestionJobResponse\x12\xa6\x01\n%UnscheduleOfflineToOnlineIngestionJob\x12=.feast_spark.api.UnscheduleOfflineToOnlineIngestionJobRequest\x1a>.feast_spark.api.UnscheduleOfflineToOnlineIngestionJobResponse\x12v\n\x15GetHistoricalFeatures\x12-.feast_spark.api.GetHistoricalFeaturesRequest\x1a..feast_spark.api.GetHistoricalFeaturesResponse\x12O\n\x08ListJobs\x12 .feast_spark.api.ListJobsRequest\x1a!.feast_spark.api.ListJobsResponse\x12R\n\tCancelJob\x12!.feast_spark.api.CancelJobRequest\x1a\".feast_spark.api.CancelJobResponse\x12I\n\x06GetJob\x12\x1e.feast_spark.api.GetJobRequest\x1a\x1f.feast_spark.api.GetJobResponse\x12g\n\x10GetHealthMetrics\x12(.feast_spark.api.GetHealthMetricsRequest\x1a).feast_spark.api.GetHealthMetricsResponseB7\n$dev.caraml.store.protobuf.jobserviceB\x0fJobServiceProtob\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'feast_spark.api.JobService_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n$dev.caraml.store.protobuf.jobserviceB\017JobServiceProto'
  _JOBTYPE._serialized_start=2034
  _JOBTYPE._serialized_end=2130
  _JOBSTATUS._serialized_start=2132
  _JOBSTATUS._serialized_end=2258
  _JOB._serialized_start=116
  _JOB._serialized_end=655
  _JOB_RETRIEVALJOBMETA._serialized_start=519
  _JOB_RETRIEVALJOBMETA._serialized_end=562
  _JOB_OFFLINETOONLINEMETA._serialized_start=564
  _JOB_OFFLINETOONLINEMETA._serialized_end=605
  _JOB_STREAMTOONLINEMETA._serialized_start=607
  _JOB_STREAMTOONLINEMETA._serialized_end=647
  _STARTOFFLINETOONLINEINGESTIONJOBREQUEST._serialized_start=658
  _STARTOFFLINETOONLINEINGESTIONJOBREQUEST._serialized_end=855
  _STARTOFFLINETOONLINEINGESTIONJOBRESPONSE._serialized_start=858
  _STARTOFFLINETOONLINEINGESTIONJOBRESPONSE._serialized_end=1001
  _SCHEDULEOFFLINETOONLINEINGESTIONJOBREQUEST._serialized_start=1004
  _SCHEDULEOFFLINETOONLINEINGESTIONJOBREQUEST._serialized_end=1136
  _SCHEDULEOFFLINETOONLINEINGESTIONJOBRESPONSE._serialized_start=1138
  _SCHEDULEOFFLINETOONLINEINGESTIONJOBRESPONSE._serialized_end=1183
  _UNSCHEDULEOFFLINETOONLINEINGESTIONJOBREQUEST._serialized_start=1185
  _UNSCHEDULEOFFLINETOONLINEINGESTIONJOBREQUEST._serialized_end=1268
  _UNSCHEDULEOFFLINETOONLINEINGESTIONJOBRESPONSE._serialized_start=1270
  _UNSCHEDULEOFFLINETOONLINEINGESTIONJOBRESPONSE._serialized_end=1317
  _GETHISTORICALFEATURESREQUEST._serialized_start=1320
  _GETHISTORICALFEATURESREQUEST._serialized_end=1484
  _GETHISTORICALFEATURESRESPONSE._serialized_start=1487
  _GETHISTORICALFEATURESRESPONSE._serialized_end=1624
  _LISTJOBSREQUEST._serialized_start=1626
  _LISTJOBSREQUEST._serialized_end=1708
  _LISTJOBSRESPONSE._serialized_start=1710
  _LISTJOBSRESPONSE._serialized_end=1764
  _GETJOBREQUEST._serialized_start=1766
  _GETJOBREQUEST._serialized_end=1797
  _GETJOBRESPONSE._serialized_start=1799
  _GETJOBRESPONSE._serialized_end=1850
  _CANCELJOBREQUEST._serialized_start=1852
  _CANCELJOBREQUEST._serialized_end=1886
  _CANCELJOBRESPONSE._serialized_start=1888
  _CANCELJOBRESPONSE._serialized_end=1907
  _GETHEALTHMETRICSREQUEST._serialized_start=1909
  _GETHEALTHMETRICSREQUEST._serialized_end=1972
  _GETHEALTHMETRICSRESPONSE._serialized_start=1974
  _GETHEALTHMETRICSRESPONSE._serialized_end=2032
  _JOBSERVICE._serialized_start=2261
  _JOBSERVICE._serialized_end=3224
# @@protoc_insertion_point(module_scope)
