"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
Legacy compatibility endpoint for older version of feast client.
The new endpoint is defined in feast_spark/api/JobService.proto
"""
import google.protobuf.descriptor

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor
